==> ModuleXtender-0.1.15.zip: ModuleXtender-0.1.15/action.showLinks.php <==
<?php
if (!isset($gCms)) exit;

// Theme hack
$themeObject = new AdminTheme($gCms,  get_userid(), get_preference(get_userid(), 'admintheme', 'default'));

if (isset($params['module_name']) && isset($params['module_id']))
{
  $links = MX_Link::doSelect(array('where' => array('modulename' => $params['module_name'], 'module_id' => $params['module_id'])));
 
  $rowclass = 'row1';
  
  foreach ($links as $link)
  {
    $link->url = $link->getUrl();
            
    $delete_url = html_entity_decode($this->CreateLink($id, 'manageLink', $returnid, 'delete links', array(
      'link_id' => $link->getId(),
    'mx_action' => 'delete',
      'js_call' => $params['js_call'],
      ), '', true));
      
    $move_up_url = html_entity_decode($this->CreateLink($id, 'manageLink', $returnid, 'move links', array(
      'link_id' => $link->getId(),
      'mx_action' => 'move_up',
      'js_call' => $params['js_call'],
      ), '', true));
      
    $move_down_url = html_entity_decode($this->CreateLink($id, 'manageLink', $returnid, 'move links', array(
      'link_id' => $link->getId(),
      'mx_action' => 'move_down',
      'js_call' => $params['js_call'],
      ), '', true));
    
    $is_new_window = html_entity_decode($this->CreateLink($id, 'manageLink', $returnid, 'change state', array(
      'link_id' => $link->getId(),
      'mx_action' => 'is_new_window',
      'js_call' => $params['js_call'],
      ), '', true));
    
    
    $manage_url = html_entity_decode($this->CreateLink($id, 'manageLinks', $returnid, 'manage links', array(
      'disable_theme' => 'true',
      'link_id' => $link->getId(),
     'js_call' => $params['js_call'],
      ), '', true));
    
    
    //   $this->ajax->GetRequestURL('ModuleXtender', 'UploadLinksBox', 'delete='.$link->getId()). // DELETE
   $link->delete = '<a onClick="javascript: callHttpWithConfirmation(\'' . $delete_url . '\', \'Are you sure?\'); ' . $params['js_call'] . '();">' .
      $themeObject->DisplayImage('icons/system/delete.gif', $this->Lang('delete'),'','','systemicon') 
        . '</a>';
   
   if ($link->getPosition() != 1)
   {
    $link->move_up = '<a onClick="javascript: callHttp(\'' . $move_up_url . '\'); ' . $params['js_call'] . '();">' .      
       $themeObject->DisplayImage('icons/system/sort_up.gif', $this->Lang('move_up'),'','','systemicon')
      // '<img src="/modules/ModuleXtender/images/icons/sort_up.gif" alt="Move up" border="0"/>'
        . '</a>';
   }
   else
   {
          $link->move_up = '';
   }
   
   if ($link->getPosition() != (count($links)))
   {
    $link->move_down = '<a onClick="javascript: callHttp(\'' . $move_down_url . '\'); ' . $params['js_call'] . '();">' .
      $themeObject->DisplayImage('icons/system/sort_down.gif', $this->Lang('move_down'),'','','systemicon') 
        . '</a>';
   }
   else 
   {
    $link->move_down = '';    
   }
      
            $link->edit = '<a href="'.$manage_url.'" target="manageLinks">' .
      $themeObject->DisplayImage('icons/system/edit.gif', $this->Lang('edit'),'','','systemicon') 
        . '</a>';
        
      if ($link->getIsNewWindow() == 1)
      {
       $link->is_new_window = '<a onClick="javascript: callHttp(\'' . $is_new_window . '\'); ' . $params['js_call'] . '();">' .      
          $themeObject->DisplayImage('icons/system/true.gif', $this->Lang('isnt_new_window'),'','','systemicon')
           . '</a>';
      }
      else
      {
        $link->is_new_window = '<a onClick="javascript: callHttp(\'' . $is_new_window . '\'); ' . $params['js_call'] . '();">' .      
           $themeObject->DisplayImage('icons/system/false.gif', $this->Lang('is_new_window'),'','','systemicon')
            . '</a>';
      }
    
    $link->rowclass = $rowclass;
    ($rowclass=="row1"?$rowclass="row2":$rowclass="row1");
  }
  

  
  
  
  if ($links)
  {
    $this->smarty->assign('xtlinks', $links);
    echo $this->ProcessTemplate('admin.showLinks.tpl');
  }
}

==> ModuleXtender-0.1.20.zip: ModuleXtender-0.1.20/action.showLinks.php <==
<?php
if (!isset($gCms)) exit;

// Theme hack
$themeObject = new AdminTheme($gCms,  get_userid(), get_preference(get_userid(), 'admintheme', 'default'));

if (isset($params['module_name']) && isset($params['module_id']))
{
  $links = MX_Link::doSelect(array('where' => array('modulename' => $params['module_name'], 'module_id' => $params['module_id'])));
 
  $categories = MX_RelatedCategory::doSelect(array('where' => array(
	'modulename' => $params['module_name'], 
	'type' => 'links')));

  $this->smarty->assign('categories', $categories);
  
  $rowclass = 'row1';
  
  foreach ($links as $link)
  {
    $link->url = $link->getUrl();
            
    $delete_url = html_entity_decode($this->CreateLink($id, 'manageLink', $returnid, 'delete links', array(
      'link_id' => $link->getId(),
    'mx_action' => 'delete',
      'js_call' => $params['js_call'],
      ), '', true));
      
    $move_up_url = html_entity_decode($this->CreateLink($id, 'manageLink', $returnid, 'move links', array(
      'link_id' => $link->getId(),
      'mx_action' => 'move_up',
      'js_call' => $params['js_call'],
      ), '', true));
      
    $move_down_url = html_entity_decode($this->CreateLink($id, 'manageLink', $returnid, 'move links', array(
      'link_id' => $link->getId(),
      'mx_action' => 'move_down',
      'js_call' => $params['js_call'],
      ), '', true));
    
    $is_new_window = html_entity_decode($this->CreateLink($id, 'manageLink', $returnid, 'change state', array(
      'link_id' => $link->getId(),
      'mx_action' => 'is_new_window',
      'js_call' => $params['js_call'],
      ), '', true));
    
    
    $manage_url = html_entity_decode($this->CreateLink($id, 'manageLinks', $returnid, 'manage links', array(
      'disable_theme' => 'true',
      'link_id' => $link->getId(),
     'js_call' => $params['js_call'],
      ), '', true));
    
    
    //   $this->ajax->GetRequestURL('ModuleXtender', 'UploadLinksBox', 'delete='.$link->getId()). // DELETE
   $link->delete = '<a onClick="javascript: callHttpWithConfirmation(\'' . $delete_url . '\', \'Are you sure?\'); ' . $params['js_call'] . '();">' .
      $themeObject->DisplayImage('icons/system/delete.gif', $this->Lang('delete'),'','','systemicon') 
        . '</a>';
   
   if ($link->getPosition() != 1)
   {
    $link->move_up = '<a onClick="javascript: callHttp(\'' . $move_up_url . '\'); ' . $params['js_call'] . '();">' .      
       $themeObject->DisplayImage('icons/system/sort_up.gif', $this->Lang('move_up'),'','','systemicon')
      // '<img src="/modules/ModuleXtender/images/icons/sort_up.gif" alt="Move up" border="0"/>'
        . '</a>';
   }
   else
   {
          $link->move_up = '';
   }
   
   if ($link->getPosition() != (count($links)))
   {
    $link->move_down = '<a onClick="javascript: callHttp(\'' . $move_down_url . '\'); ' . $params['js_call'] . '();">' .
      $themeObject->DisplayImage('icons/system/sort_down.gif', $this->Lang('move_down'),'','','systemicon') 
        . '</a>';
   }
   else 
   {
    $link->move_down = '';    
   }
      
            $link->edit = '<a href="'.$manage_url.'" target="manageLinks">' .
      $themeObject->DisplayImage('icons/system/edit.gif', $this->Lang('edit'),'','','systemicon') 
        . '</a>';
        
      if ($link->getIsNewWindow() == 1)
      {
       $link->is_new_window = '<a onClick="javascript: callHttp(\'' . $is_new_window . '\'); ' . $params['js_call'] . '();">' .      
          $themeObject->DisplayImage('icons/system/true.gif', $this->Lang('isnt_new_window'),'','','systemicon')
           . '</a>';
      }
      else
      {
        $link->is_new_window = '<a onClick="javascript: callHttp(\'' . $is_new_window . '\'); ' . $params['js_call'] . '();">' .      
           $themeObject->DisplayImage('icons/system/false.gif', $this->Lang('is_new_window'),'','','systemicon')
            . '</a>';
      }
    
    $link->rowclass = $rowclass;
    ($rowclass=="row1"?$rowclass="row2":$rowclass="row1");
  }
  

  
  
  
  if ($links)
  {
    $this->smarty->assign('xtlinks', $links);
    echo $this->ProcessTemplate('admin.showLinks.tpl');
  }
}
